%script that will take the result of the TobiiExtract script and create a
%.csv file for each participant, as well as a single file that concatenates
%all the participants into one long-form data. Also create a third file
%that contains summary data for each participant

clc; clear;

%1=suppress file names
[matfls matpathname nFiles] = selectFiles('mat',1);

for i = 1:nFiles
    
    %make sure filename is in correct format
    flname = fnameFormat(matfls, i);
    load(flname);
    
    fprintf('\n*** %s ***\n\n', flname);

    
%----- INDIVIDUAL FILE

    pval = flname(1:end-14);
    fid = fopen(strcat(pval, '.csv'),'w');
    
    %write headers
    hdrInd = {'pno', 'trialDur', 'nChangeSelection', 'selection',...
        'selectionTime', 'fixNo', 'Xloc', 'Yloc', 'maxErrorPixels', 'fixROI', ...
        'fixOnset', 'fixOffset', 'fixDur'};
    
    for h = 1:length(hdrInd)
        fprintf(fid,'%s,',hdrInd{h});
    end
    fprintf(fid,'\n');
    
    %grab values to print to data
    for roiT = length(eyeData.mouse.ROI)-1:-1:1
        if ~strcmp(eyeData.mouse.ROI{roiT}, 'No_ROI')
            eyeData.trial.selectTime = eyeData.mouse.time(roiT);
            break;
        end
    end
    
    if ~isfield(eyeData.trial, 'selectTime')
        eyeData.trial.selectTime=-10;
    end
    
    %if maxError is blank, fill in the missing values
    if length(eyeData.eye.maxError) < length(eyeData.eye.ROI)
        strtval = length(eyeData.eye.maxError);
        endval = length(eyeData.eye.ROI);
        eyeData.eye.maxError(strtval:endval)=-10;
    end
    
    
    %write data
    for x = 1:length(eyeData.eye.x)
        fprintf(fid, '%s,', pval);
        fprintf(fid, '%1.3f,', eyeData.trial.trialdur, eyeData.trial.nChangeSelection);
        fprintf(fid, '%s,', eyeData.trial.selection);
        fprintf(fid, '%1.3f,', eyeData.trial.selectTime, x, eyeData.eye.x(x), ...
            eyeData.eye.y(x), eyeData.eye.maxError(x));
        fprintf(fid, '%s,', eyeData.eye.ROI{x});
        fprintf(fid, '%1.3f,', eyeData.eye.onset(x), eyeData.eye.offset(x),...
                                eyeData.eye.dur(x));
        fprintf(fid, '\n');
    end
    
    fclose(fid);
    
    

    
%----- LOG INDIVIDUAL FILES
    if ~exist('fid2','var')
        fid2 = fopen('longData.csv','w');
        
        for h = 1:length(hdrInd)
            fprintf(fid2,'%s,',hdrInd{h});
        end
        fprintf(fid2,'\n');
    end
    
    %write data
    for k = 1:length(eyeData.eye.x)
        fprintf(fid2, '%s,', pval);
        fprintf(fid2, '%1.3f,', eyeData.trial.trialdur, eyeData.trial.nChangeSelection);
        fprintf(fid2, '%s,', eyeData.trial.selection);
        fprintf(fid2, '%1.3f,', eyeData.trial.selectTime, k, eyeData.eye.x(k), ...
            eyeData.eye.y(k), eyeData.eye.maxError(k));
        fprintf(fid2, '%s,', eyeData.eye.ROI{k});
        fprintf(fid2, '%1.3f,', eyeData.eye.onset(k), eyeData.eye.offset(k), ...
            eyeData.eye.dur(k));
        fprintf(fid2, '\n');
    end
    

    
%----- SUMMARY FILE
    fid3 = fopen(strcat(pval, '_sum.csv'),'w');
    
    
    %write headers
    hdrSum = {'pno', 'trialDur', 'nChangeSelection', 'selection',...
        'selectionTime', 'nfixClub', 'nfixSpade', 'nfixDiamond', 'nfixText', ...
        'nfixArrow', 'gazedurClub', 'gazedurSpade', 'gazedurDiamond', ...
        'gazedurText', 'gazedurArrow', 'aveFixDurClub', 'aveFixDurSpade', ...
        'aveFixDurDiamond', 'aveFixDurText', 'aveFixDurArrow', 'nSwitch_CSD', 'nSwitch_CD'};
    
    for h = 1:length(hdrSum)
        fprintf(fid3,'%s,',hdrSum{h});
    end
    fprintf(fid3,'\n');
    
    
    
    %calculations
    nspade=0; nclub=0; ndiam=0; ntext=0; narrow=0;
    gspade=0; gclub=0; gdiam=0; gtext=0; garrow=0;
    aveclub=[]; avespade=[]; avediam=[]; avetext=[]; avearrow=[];
    nswitchCSD=0; nswitchCD=0;
    
    for m=1:length(eyeData.eye.ROI)
        
        if strcmp(eyeData.eye.ROI{m}, 'Club')
            nclub = nclub+1;
            gclub=gclub+eyeData.eye.dur(m);
            aveclub=[aveclub eyeData.eye.dur(m)];
            
        elseif strcmp(eyeData.eye.ROI{m}, 'Spade')
            nspade = nspade+1;
            gspade=gspade+eyeData.eye.dur(m);
            avespade=[avespade eyeData.eye.dur(m)];
            
        elseif strcmp(eyeData.eye.ROI{m}, 'Diamond')
            ndiam = ndiam+1;
            gdiam=gdiam+eyeData.eye.dur(m);
            avediam=[avediam eyeData.eye.dur(m)];
            
        elseif strcmp(eyeData.eye.ROI{m}, 'Text')
            ntext = ntext+1;
            gtext=gtext+eyeData.eye.dur(m);
            avetext=[avetext eyeData.eye.dur(m)];
            
        elseif strcmp(eyeData.eye.ROI{m}, 'Arrow')
            narrow = narrow+1;
            garrow=garrow+eyeData.eye.dur(m);
            avearrow=[avearrow eyeData.eye.dur(m)];
            
        end
        
        %switch from one of the three items to one of the other three items
        if m ~= length(eyeData.eye.ROI)
            if ~strcmp(eyeData.eye.ROI{m}, eyeData.eye.ROI{m+1}) && ...
                (strcmp(eyeData.eye.ROI{m}, 'Club') || ...
                strcmp(eyeData.eye.ROI{m}, 'Spade') || ...
                strcmp(eyeData.eye.ROI{m}, 'Diamond')) && ...
                (strcmp(eyeData.eye.ROI{m+1}, 'Club') || ...
                strcmp(eyeData.eye.ROI{m+1}, 'Spade') || ...
                strcmp(eyeData.eye.ROI{m+1}, 'Diamond'))
                
            
            	nswitchCSD = nswitchCSD+1;
            end
            
            if ~strcmp(eyeData.eye.ROI{m}, eyeData.eye.ROI{m+1}) && ...
                (strcmp(eyeData.eye.ROI{m}, 'Club') ||  ...
                strcmp(eyeData.eye.ROI{m}, 'Diamond')) && ...
                (strcmp(eyeData.eye.ROI{m+1}, 'Club') || ...
                strcmp(eyeData.eye.ROI{m+1}, 'Diamond'))
            
            	nswitchCD = nswitchCD+1;
            end
            
        end
        
    end
    
    
    %average fixation duration
    if ~isempty(aveclub)
        aveclub = mean(aveclub);
    else
        aveclub=-10;
    end
    
    if ~isempty(avespade)
        avespade = mean(avespade);
    else
        avespade=-10;
    end
    
    if ~isempty(avediam)
        avediam = mean(avediam);
    else
        avediam=-10;
    end
    
    if ~isempty(avetext)
        avetext = mean(avetext);
    else
        avetext=-10;
    end
    
    if ~isempty(avearrow)
        avearrow = mean(avearrow);
    else
        avearrow=-10;
    end
    
    
    %write data
    fprintf(fid3, '%s,', pval);
    fprintf(fid3, '%1.3f,', eyeData.trial.trialdur, eyeData.trial.nChangeSelection);
    fprintf(fid3, '%s,', eyeData.trial.selection);
    fprintf(fid3, '%1.3f,', eyeData.trial.selectTime, nclub, nspade, ndiam, ntext, ...
        narrow, gclub, gspade, gdiam, gtext, garrow, aveclub, avespade, avediam, ...
        avetext, avearrow, nswitchCSD, nswitchCD);
    
    fclose(fid3);
    
    
%----- LOG SUMMARY FILES
    if ~exist('fid4','var')
        fid4 = fopen('longData_Sum.csv','w');
        
        for h = 1:length(hdrSum)
            fprintf(fid4,'%s,',hdrSum{h});
        end
        fprintf(fid4,'\n');
    end
    
    %write data
    fprintf(fid4, '%s,', pval);
    fprintf(fid4, '%1.3f,', eyeData.trial.trialdur, eyeData.trial.nChangeSelection);
    fprintf(fid4, '%s,', eyeData.trial.selection);
    fprintf(fid4, '%1.3f,', eyeData.trial.selectTime, nclub, nspade, ndiam, ntext, ...
        narrow, gclub, gspade, gdiam, gtext, garrow, aveclub, avespade, avediam, ...
        avetext, avearrow, nswitchCSD, nswitchCD);
    fprintf(fid4,'\n');
    
   
    save(flname, 'eyeData', 'cfg');
    clear eyeData;
    
    
end

disp('finished');
    
    