function TobiiExtract
%TobiiExtract
%
%   Opens a Tobiii-generated Data File (.txt) and processes the data ready
%   for analysis. After running this script, run MatToCSV_Tobii, in this
%   directory, to convert .mat files into excel-friendly csv files
%
%
%       
%                       ***************************************************
%                       Created by Chris Street (cstreet1986@gmail.com),
%                       Aug 2014. Use with caution, always check your raw
%                       data match this output.
%                       ***************************************************
%
%% inputs & variables
% 
% if nargin == 0
%     
%     %select .mat files
%     [filename pathname] = selectFiles('mat');
% %     cfg.orig_mat_name = filename;
%     addpath(pathname);
%             
% elseif nargin == 1
%     disp('.mat and .txt files must be in this directory or subdirectory');
%     addpath(genpath(cd));
%     
% end


%% set defaults

%cfg is a "configuration" structure. Check out the initialise function and
%see what gets set into it. Hopefully most of the changes you'll need to
%make are in there.

cfg=initialise;
cfg=configCheck(cfg); %check everything is filled


%% get filename(s)

%get the eyedata files
[fls_eye eyepathname] = getFilename(cfg);


%% parse data & analyse

if ischar(fls_eye)
    nF = 1;
else
    nF = length(fls_eye);
end

%for each file (usually 1 file = 1 subject)
for i = 1:nF
    
    %make sure filename is in correct format
    flname = fnameFormat(fls_eye, i);
    
    fprintf('\n*** %s ***\n\n', flname);
    

%% READ EYE DATA FILE
    
    
    %check to see if it has been processed before. If so, ask if you want
    %to reprocess (processing takes some time)
    processCheck = flname(1:length(flname)-4);
    processCheck = strcat(processCheck, '_processed.mat');
    if exist(processCheck, 'file') && ~exist('getDat', 'var')
        getDat = input('Process file already exists. Reprocess? 1=Yes [default]: ');
    elseif ~exist('getDat','var')
        getDat = 1;
    end
    
    if isempty(getDat)
        getDat = 1;
    end
    
    
    % ** run through txt file
    % the file_fUnknown us a horrible function. It reads in each line of
    % the raw data file and will attempt to determine what is in each line.
    % 
    if getDat == 1
        eyeData = file_fUnknown(flname, eyepathname, cfg); % << READ EYE DATA
    elseif exist(processCheck, 'file')
        load(processCheck); %load data
    else
%         disp('File not found in directory. Processing raw data.')
        eyeData = file_fUnknown(flname, eyepathname, cfg);
    end
   
    
%% save data

    %save processed data to a .mat file
    saveData(flname, eyeData, cfg);

   
%% WRITE DATA TO FILE
    

    if cfg.writetofile > 0
        %write csv files for each of the phases of the expt. This is just
        %the raw data for this participant.
        
        
        if ischar(cfg.pixperdegloc)
            eval(['pixperdg=' cfg.pixperdegloc ';']);
        else
            pixperdg = cfg.pixperdegloc;
        end
        
        %convert visual degrees to pixels
        err=err*pixperdg;
        
        eyeData = writerawELfile(eyeData, matname, cfg);
    
                    
        save(filname, 'eyeData');
        
    end
    
    
%     %------------------------
%     %WRITE PROCESSED DATA TO FILE
%     %processed data is the means for each participant for relevant
%     %measures. This comes from another script, and will not function
%     correctly here
%     
%     if cfg.writetofile == 1
%         if exist('DATA', 'var')
%             writeProcessedFile(eyeData, matname, cfg, filname, DATA);
%         else
% %             error('need to use the behavioural data');
%             writeProcessedFile(eyeData, matname, cfg, filname);
%         end
%     end

    close('all');
     
end


disp('Finished');

end



%% **************************************************
%****************************************************
%                EMBEDDED FUNCTIONS
%****************************************************
%****************************************************



%% -*****************


    
    function [fls_eye eyepathname] = getFilename(cfg)
        %if we're reading all files
        if cfg.readall == 1
            fls_eye = dir(strcat(cd, '/*.txt'));
        %   fls_asc(strncmp({fls_asc.name},'iH',5)) = []; %remove any file not beginning with iH

        elseif cfg.readall == 0
            fls_eye.name = strcat(filename, '.txt'); %create name for single file

        elseif cfg.readall == 2

%             fprintf('\n.TXT and .MAT files must be in same directory\n');
            %select .asc files
            [fls_eye eyepathname] = selectFiles('txt',1);
            addpath(eyepathname);

        end

    end

    
    function flname = fnameFormat(fls_asc, i)
    
        %make sure variable is of correct type
        if isstruct(fls_asc)
            flname = fls_asc(i).name;
        elseif iscell(fls_asc)
            flname = fls_asc{i};
        elseif ischar(fls_asc)
            flname = fls_asc;
        end
        
    end