%   The input argument cfg is a structure that has the following
%   fields. Defaults will be provided for any missing fields:
%
%       1. firstfix: 0 [default] = ignore first fixation (useful if there 
%             is a central fixation spot preceding the onset of the trial), 
%             1 = use first fixation.
%
%       2. readall: 0 = read single file, 1 = read all files in this
%             directory, 2 [default] = select directory using operating
%             system navigation.
%
%       3. orig_mat_name: optional. name of behavioural data file, if
%              appropriate. Requires that the behavioural data is saved in
%              .mat format, and assumes the participant number prefixes
%              the filename.
%
%       4. writetofile: 1 [default] = write data to a csv file, 0 = do
%              not. columns = pno, trial ID, fixation number, x, y, duration, 
%              pupil size [, response, RT] (square bracketed
%              terms only written to datafile if the original mat files
%              generated by the experiment have been read, i.e. if
%              use_orig_mat == 1). Not an exhaustive list.
%
%       5. movefiles: 1 [default] = organise picture files (only operates
%              if draw_fixes == 1), 0 = leave all files in current
%              directory.
%
%       6. idxDisp: The script will likely have to process thousands of lines
%              of data from the eyetracking data file. It does so
%              line by line. By default, as the script reaches a new 
%              trial it will print this to the command window. However,
%              you may want to see the row number you're currently at.
%              cfg.idxDisp allows you to set how often you want the row
%              number to be printed. E.g. if you want to see where the file
%              is at every 200 rows, set cfg.idxDisp to 200. Setting it to
%              0 (default) turns off the screen printing.
%
%       7. trialDisp: As above, but printing out trial numbers rather than
%               indexes. Defaults to showing all trials.
%
%       8. minFixDur: minimum duration (msec) that a fixation must be stable
%              for before recording it as a fixation. Discard anything
%              shorter than this duration. Suggested that this is set to
%              100, following Viviani (1990), although your needs may
%              differ.
%
%       9. debugTrial: trial on which to stop for debugging (optional).
%              This will not automatically stop the code. Rather, you will
%              need to enter a breakpoint at the relevant line in this
%              function where the conditional "if trial number is equal to
%              cfg.debugTrial" is written.
%
%       10. suppressnofix: when set to 1, the script prints to the command
%               window a notice whenever the fixation is not in any of the
%               regions of interest. On some tasks you may find this to be
%               the rule rather than the exception. In which case, you may
%               want to set it to 0, to suppress the warnings. Default is
%               1.
%
%       11. pixperdegloc: this is either a string identifying where in the
%               behavioural data variables we can find the number of pixels
%               per visual degree, or is itself the number that we're 
%               looking for (cfg.pixperdegloc = 'DATA.pixperdeg' and
%               cfg.pixperdegloc = 53 are both acceptable). Set to -1 to
%               skip use of visual degrees.
%
%       
%       >> ELidentifiers structure
%
%       12.   ELidentifiers.secname: a cell of strings that identify the onset and
%               offset of each section of the trial. For example, if there
%               are only "START TRIAL" and "END TRIAL" messages in the
%               ASCII file, then you could use "START" and "END" as the
%               two identifier strings. You might have PRE and POST
%               sections to your trial, in which case you would need
%               another identifier between the start and end of the trial.
%               Note also that the onset of the trial and the onset of
%               recording are usually not the same thing: recording begins
%               before the onset of the trial.
%
%       13.   ELidentifiers.secpos: the script runs through each line of the
%               data file in turn. After grabbing a line, you need to
%               identify which word of the message will be the
%               [ELidentifier.name] item. E.g. if the message was "MSG
%               START TRIAL", then it would be the second word
%               (ELidentifier.pos = 2)
%
%       14.   ELidentifiers.secposval: the position in the string where the
%               unique identifying value will be found. For example,
%               "MSG SECTION 3" has the unique identifier in the third
%               position (section #3). If irrelevant, set to -1
%
%       15.   ELidentifiers.recordname: the string IDs that identify the 
%               start of recording and end of recording. You might want to
%               collect the trial number (TRIALID) and other data from
%               these lines too, in which case you will need to specify
%               the position of the value (see Elidentifiers.recordvalpos)
%               other means of identifying trials.
%
%       16.   Elidentifiers.recordpos: the position of the
%               ELidentifiers.recordnames in the string. For example, "MSG
%               TRIALID 1" has the identifying string in the second
%               position (TRIALID)
%
%       17.   ELidentifiers.recordposval: the position in the string where the
%               unique identifying value will be found. For example,
%               "MSG TRIALID 1" has the unique identifier in the third
%               position (trial #1). The first message MUST be the
%               recording onset and the last message MUST be the end of
%               recording.
%
%       18.   ELidentifiers.respname: optional. If present, is a string
%               of the line identifier where the response value can be
%               found
%
%       19.   ELidentifiers.resppos: optional. Where the respname string
%               can be found
%
%       20.   ELidentifiers.respposval: optional. The position where the
%               value to return can be found
%
%
%       21.   ELidentifiers.RTname: optional. The string identifying the
%               line where RT information can be found
%
%       22.   ELidentifiers.RTpos: optional. Where the RTname string can be
%               found in the line
%
%       23.   ELidentifiers.RTposval: optional. Where the value to be
%               returned can be found in this line
%
%       
%       >> ROI structure
%
%       24.   ROI.x1: left X-location of the rectangle ROI you want to draw.
%               Each entry represents the left side of each ROI
%
%       25.   ROI.y1: top Y-location of each rectangle ROI.
%
%       26.   ROI.x2: right X-location of each rectangle ROI.
%
%       27.   ROI.y2: bottom Y-location of each rectangle ROI.
%
%       28.   ROI.name: name of the ROI rectangle, as a {cell}.
%