function eyeData = file_fUnknown(filename, ascpath, cfg)

% Read data with unknown format and parse eye movement data. Saves data to
% the eyeData(i) structure. Importantly, this version assumes there is ONLY
% 1 TRIAL. So it will read through all the data until it fines the start of
% a trial, and then when it finds the end of the trial it will assume that
% is all the data you wanted to collect.
%



%predefine variables
foundStart = 0;
foundEnd = 0;
idx=0;
if cfg.firstfix == 1 %we are using the first fixation
    firstfix = 0; %already skipped it
else
    firstfix = 1; 
end


xcountr=1;
ycountr=1;
countr=1;
mcountr=1;
currentROI='blank';
nChange=-1;



fixate=0;
mindur = cfg.minFixDur;

%open file
fid = fopen(filename);
if fid == -1
    addpath(genpath(cd)); %check subfolders
    fid = fopen(strcat(ascpath, filename));
    if fid == -1
        error(['Error Opening ',filename]);
    end
end


%read each new line of the file
% while ~feof(fid)
while foundStart == 0 && ~feof(fid)
% for i = 1:14 %debug
    
    dataLine = fgetl(fid);
    textParse = strread(dataLine, '%s','delimiter','\t');
    idx = idx+1;

    %need textParse to have at least 3 cells. If it doesn't, we are not in
    %the relevant row. Ignore all other commands. This will also prevent
    %the code from erroring when it tries to read textParse that has too
    %few elements
    if size(textParse, 1) >= min(cfg.ELidentifiers.recordpos)+1

        %%*********
        %if the start of the trial, begin collecting data.
        %*********

        if strcmp(textParse(cfg.ELidentifiers.recordpos(1)), ...
                        cfg.ELidentifiers.recordnames{1})

            foundStart = 1;
            startRow = idx;
            fprintf('Start trial at row %i\n', startRow);
            startTrialTime = str2double(textParse(11));
            
        end
            
        
    end
end

%did we find a trial?
if foundStart == 0
    error('did not find a trial');
end


while foundEnd == 0 && ~feof(fid)
    
    %display every ith index
    if rem(idx,cfg.idxDisp) == 0, fprintf('idx: %i\n',idx); end
    
    
    %if end of the trial
    if strcmp(textParse(cfg.ELidentifiers.recordpos(end)), cfg.ELidentifiers.recordnames{end})
        
        %should we still be fixating by the end of the trial
        if fixate == 1 && endTime-currentTime >= mindur %make sure it's longer than min duration
            eyeData.eye.x(countr) = mean(X);
            eyeData.eye.y(countr) = mean(Y);
            eyeData.eye.onset(countr) = currentTime-startTrialTime;
            eyeData.eye.offset(countr) = endTime-startTrialTime;
            eyeData.eye.dur(countr) = endTime-currentTime;
            eyeData.eye.ROI{countr} = char(currentROI);
            countr = countr+1;
        end
        
        fixate = 0;
        foundEnd = 1;
        
        %trial information
        endT = eyeData.eye.offset(end);
        eyeData.trial.startTrialTime = startTrialTime;
        eyeData.trial.trialdur = str2double(textParse(11))-startTrialTime;
        if ~exist('lastSelect','var')
            eyeData.trial.selection = 'NoSelection';
            eyeData.trial.nChangeSelection = 0;
            eyeData.trial.changeTime = NaN;
        else
            eyeData.trial.selection = lastSelect;
            eyeData.trial.nChangeSelection = nChange;
            eyeData.trial.changeTime = changeTime(2:end);
        end
        
        
        
        
    %if (possibly) starting a fixation
    elseif fixate == 0 && length(textParse)>25
        
        %first line of fixation: check that it's really a fixation
        for j = 1:length(cfg.ROI.name)
            if strcmp(cfg.ROI.name{j},textParse(26))
                cont=1; %continue
                break
            else
                cont=0; %don't continue
            end
        end
        
        if cont==1
            fixate=1;
            X(xcountr) = str2double(textParse(24)); xcountr=xcountr+1;
            Y(ycountr) = str2double(textParse(25)); ycountr=ycountr+1;
            currentROI = textParse(26);
            currentTime = str2double(textParse(11));
            endTime=currentTime;
        end
    
    %if within the same fixation
    elseif fixate == 1 && length(textParse)>25 && strcmp(currentROI,textParse(26))
        
        %get data

        for j = 1:length(cfg.ROI.name)
            if strcmp(cfg.ROI.name{j},textParse(26))
                cont=1; %continue
                break
            else
                cont=0; %don't continue
            end
        end
        
        if cont==1
            X(xcountr) = str2double(textParse(24)); xcountr=xcountr+1;
            Y(ycountr) = str2double(textParse(25)); ycountr=ycountr+1;
            endTime = str2double(textParse(11));
        end
        
    %end of same fixation - summarise data for this fixation
    elseif fixate == 1 && length(textParse)>25 && ...
                 (isempty(textParse(26)) || ~strcmp(currentROI,textParse(26)))
        
        if endTime-currentTime >= mindur %make sure it's longer than min duration
            if firstfix == 0
                
                eyeData.eye.x(countr) = round(mean(X));
                eyeData.eye.y(countr) = round(mean(Y));
                eyeData.eye.onset(countr) = currentTime-startTrialTime;
                eyeData.eye.offset(countr) = endTime-startTrialTime;
                eyeData.eye.dur(countr) = endTime-currentTime;
                eyeData.eye.ROI{countr} = char(currentROI);
                eyeData.eye.maxError(countr) = max([max(X)-min(X) max(Y)-min(Y)]);
                countr = countr+1;
                
            else
                firstfix = 0;
            end
            
            xcountr=1; ycountr=1; currentROI='x'; fixate = 0;
            clear X Y currentTime endTime;
            
        end
        
    end
    
    
    %check for MOUSE PRESS
    
    for n = 25:length(textParse)
        
        if strcmp(textParse(n), cfg.ELidentifiers.respname)
            eyeData.mouse.x(mcountr) = str2double(textParse(n+1));
            eyeData.mouse.y(mcountr) = str2double(textParse(n+2));
            eyeData.mouse.time(mcountr)  = str2double(textParse(11))-startTrialTime;
            
            %identify what the mouse selected, if anything
            for nBtn = 1:length(cfg.mouse.x1)
                if eyeData.mouse.x(mcountr) > cfg.mouse.x1(nBtn) && ...
                        eyeData.mouse.x(mcountr) < cfg.mouse.x2(nBtn) && ...
                        eyeData.mouse.y(mcountr) > cfg.mouse.y1(nBtn) && ...
                        eyeData.mouse.y(mcountr) < cfg.mouse.y2(nBtn)
                    
                    eyeData.mouse.ROI{mcountr} = cfg.mouse.name{nBtn};
                    
                    %what's the last selected item before ending trial?
                    if ~strcmp(cfg.mouse.name{nBtn},'Arrow_mouse')
                        lastSelect = cfg.mouse.name{nBtn};
                        nChange = nChange + 1;
                        if exist('changeTime','var')
                            changeTime = [changeTime eyeData.mouse.time(mcountr)];
                        else
                            changeTime = eyeData.mouse.time(mcountr);
                        end
                    end
                    
                    break
                    
                else
                    eyeData.mouse.ROI{mcountr} = 'No_ROI';
                end
        
            end
            
            mcountr=mcountr+1;
            break;
        end
        
        
    end %go through each item of this row of data, check for mouse press
    
    
    
    idx = idx + 1;
    %get a new line
    dataLine = fgetl(fid);
    textParse = strread(dataLine, '%s','delimiter','\t');
    
end

%close file
fclose(fid);

end
    
    
    
    
%--------------------

    function eyeData = getTrackerError(eyeData, textParse, checkVal)

    
        if checkVal == 0
            if binoc == 1
                if trialno == 0 && strcmp(textParse(7), 'LEFT')
                    eyeData(1).leftErrAve = str2double(textParse(10));
                    eyeData(1).leftErrMax = str2double(textParse(12));
                elseif trialno == 0 && strcmp(textParse(7), 'RIGHT')
                    eyeData(1).rightErrAve = str2double(textParse(10));
                    eyeData(1).rightErrMax = str2double(textParse(12));
                end
            else
                eyeData(1).rightErrAve = str2double(textParse(10));
                eyeData(1).rightErrMax = str2double(textParse(12));
            end

       elseif checkVal == 1
            if binoc == 1
                if trialno == 0 && strcmp(textParse(7), 'LEFT')
                    eyeData(trialno).leftErrAve = str2double(textParse(10));
                    eyeData(trialno).leftErrMax = str2double(textParse(12));
                elseif trialno == 0 && strcmp(textParse(7), 'RIGHT')
                    eyeData(trialno).rightErrAve = str2double(textParse(10));
                    eyeData(trialno).rightErrMax = str2double(textParse(12));
                end
            else
                eyeData(1).rightErrAve = str2double(textParse(10));
                eyeData(1).rightErrMax = str2double(textParse(12));
            end
        end
            
    end