function eyeData = writerawELfile(eyeData, matname, cfg)
%write data for each phase of the experiment.
%   columns = pno, trial ID, choice,
%   fixation number, x, y, duration, pupil size, confidence,
%   decision time, confidence response time.


writefilename = strcat(matname, '_raw.csv');
pno = data.demog.identifier;         %get pno >> NEEDS TO BECOME GENERALISED
%ensure value is numeric

if ~isnumeric(pno)
    str2double(pno);
end


fid = fopen(writefilename, 'w');

                                                                % <<< NEEDS TO BECOME GENERALISED

hdrA = {'pno', 'age', 'sex', 'dist_from_screen', ...
    'stimsize_degX', 'stimsize_degY', 'trialID', 'block'};

hdrC = {'response', 'fixation_no',...
    'x', 'y', 'ROInum', 'ROIname', 'fixdur', ...
    'trialduration'};
    
    %need to add three more columns: saccade towards/away from target
    %(distance), average distance to number of noisy and stable
    %distractors within a given region, and the number of noisy/stable
    %distractors within that region

for h = 1:length(hdrA)
    fprintf(fid, '%s,', hdrA{h});
end

if length(cfg.ELidentifiers.recordpos) > 2
    for x = 1:length(cfg.ELidentifiers.recordpos)-2
         fprintf(fid, '%s,', cfg.ELidentifiers.recordnames{x+1});
    end
end

for h = 1:length(hdrC)
    fprintf(fid, '%s,', hdrC{h});
end

fprintf(fid, '\n'); %new line


nofixcount.no = 0; %count number of fixations not inside an ROI
nofixcount.tot = 0; %count number of fixations not inside an ROI


for i = 1:size(eyeData,2) %for all trials
    
    if i == cfg.debugTrial
        fprintf('\ndebug at line 57 for raw file writing\n');
    end
    
    
    %if there are any fixations on this trial
    if isfield(eyeData(i), 'x')
        
        %DATA.trials(i,:) = [trialID, repeat(1***)/new(2***)/quad(**X*), block, Tloc, 
        %                    Tid, Torient (2L 4R), keyPress, Acc, RT]
        
        
        %for all fixations
        for nfix = 1:length(eyeData(i).x)
           
            
            %ROI size
%             eyeData(i).stimpix = 70;
%             for x = 1:size(cfg.ROI.x1)
%                 eyeData(i).ROIsizeX(x) = cfg.ROI.x2(x) - cfg.ROI.x1(x);
%                 eyeData(i).ROIsizeY(x) = cfg.ROI.y2(x) - cfg.ROI.y1(x);
%             end
            
            
            %does fixation fall into ROI?
            
            
            
            
            hdrA = {'pno', 'age', 'sex', 'dist_from_screen', ...
                'stimsize_degX', 'stimsize_degY', 'trialID', 'block'};

            hdrC = {'response', 'fixation_no',...
                'x', 'y', 'ROInum', 'ROIname', 'fixdur', ...
                'trialduration'};


            
            %print to file
            fprintf(fid, '%i,', pno, DATA.age);
            fprintf(fid, '%s,', DATA.sex, DATA.hand);
            fprintf(fid, '%1.2f,', DATA.scrdist_mm, DATA.stimsize_deg, i, eyeData(i).block, ...
                eyeData(i).patternID, eyeData(i).repeat, eyeData(i).quadrant, ...
                eyeData(i).targetpos, eyeData(i).orient, eyeData(i).resp, ...
                eyeData(i).acc, nfix, eyeData(i).x(nfix), eyeData(i).y(nfix), ...
                eyeData(i).ROI(nfix), eyeData(i).fixdur(nfix), DATA.trials(i,9), ...
                eyeData(i).nearestStim(nfix), eyeData(i).nearestNoisy(nfix),...
                eyeData(i).nearestStable(nfix), eyeData(i).aveNearestNNoisy(nfix),...
                eyeData(i).aveNearestNStable(nfix), cfg.numnearest, eyeData(i).NnoisyInSpan, ...
                eyeData(i).NstableInSpan, eyeData(i).NtargetInSpan, ...
                spanpix, spandeg, eyeData(i).epoch);
            
            if cfg.valpatt == 1
                fprintf(fid, '%i,', eyeData(i).validPattern);
            end
            
            fprintf(fid, '\n');
         
        end
            
    else
        fprintf('[RAW] No fix duration for trial %i.\nUse first fix = %i.',...
                     i, cfg.firstfix);
    end
    
    
end

fclose(fid);

fprintf('\n\n fixations outside ROIs: %i of %i\n\n', nofixcount.no, nofixcount.tot);

if cfg.movefiles == 1
    %move csv file
    if ~exist('5.datafiles/Raw', 'dir')
        mkdir('5.datafiles/Raw');
    end

    dest = strcat(cd, '/5.datafiles/Raw');
    movefile(writefilename, dest, 'f');
end

end